var indexSectionsWithContent =
{
  0: "cdgjmpqs",
  1: "j",
  2: "q",
  3: "cgmps",
  4: "j",
  5: "j",
  6: "dq"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "variables",
  5: "groups",
  6: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Variables",
  5: "Modules",
  6: "Pages"
};

